/* @(#) $Id: Program.cs,v 1.1 2013/06/13 10:15:57 elke Exp $
 ****************************************************************************
 * COPYRIGHT , 1996-2007                                                   *
 * Hans-Joachim Bothe, Andreas Hofmann, Karst Schaap, Michael Ziller        *
 ****************************************************************************
 * HighqSoft GmbH                                                           *
 * Schlossborner Weg 6b, D-61479 Glashtten/Taunus, Germany                 *
 * Phone: +49 6174 62915, Fax: +49 6174 62935, Internet: www.highqsoft.com  *
 ****************************************************************************
 *                                                                          *
 * All Rights Reserved.                                                     *
 *                                                                          *
 * This software is the confidential and proprietary information of the     *
 * authors. It may be freely copied and distributed with the following      *
 * stipulations:                                                            *
 *                                                                          *
 *      o No fee except to recover costs of media and delivery may          *
 *        be charged for the use or possession of this software.            *
 *      o Sources to this utility must be made available in machine-        *
 *        readable form along with the executable form.                     *
 *      o No portion of this program may be used in any program sold        *
 *        for a fee or used for production purposes.                        *
 *      o This copyright notice must not be removed.                        *
 *                                                                          *
 * All brand names and product names used in this software are trademarks,  *
 * registered trademarks, or trade names of their respective holders.       *
 * The authors of this software are not associated with any product or      *
 * vendor mentioned in the code or documentation.                           *
 *                                                                          *
 ****************************************************************************
*/

using System;
using System.IO;
using System.Collections.Generic;
using System.Text;
using System.Runtime.Remoting.Channels;
using omg.org.CosNaming;
using Ch.Elca.Iiop;
using Ch.Elca.Iiop.Services;
using org.asam.ods;

/*
 A small testprogramm.
 It uses the library generated by the IIOP.NET.
 
 This program is available at iiop-net.sourceforge.net.
 
 This project is maintained by Elca Informatique SA and was developed in 
 collaboration with the Programming Languages and Runtime 
 Systems Research Group of the ETH-Zurich as part of Dominic Ullmann's diploma thesis. 
*/

namespace ASAMODSTest {
   class Program {

      /*
       * The main program.
       */
      static void Main(string[] args) {

         // Initialize a CORBA client channel.
         IiopClientChannel channel1 = new IiopClientChannel();
         ChannelServices.RegisterChannel(channel1, false);

         // Initialize the CORBA environment.
         CorbaInit init = CorbaInit.GetInit();

         // Get the name service from host TESTSERVER:2809
         NamingContext nameService = init.GetNameService("TESTSERVER", 2809);

         // Get the name service component TestModel/DB.ASAM-ODS
         NameComponent[] name = new NameComponent[] { new NameComponent("TestModel/DB", "ASAM-ODS") };

         // Resolve the ASAM ODS factory.
         Object obj = nameService.resolve(name);
         AoFactory aoFactory = (AoFactory)obj;

         try {

            // Crate a new ASAM ODS session.
            AoSession session = aoFactory.newSession("USER=karst, PASSWORD=secret");

            // Get the application structure.  
            ApplicationStructure asObj = session.getApplicationStructure();

            // Write the session context to EXCEL.
            // sessionContextToExcel(session);
            sessionContextToConsole(session);

            // Send an informational message to the console.
            System.Console.WriteLine("Connection was successfully established.");
            
         } catch (AoException aoe) {
            System.Console.WriteLine(aoe.reason);
         }
      }

      /**
       * Print the context varibales to the console.
       */
       static private void sessionContextToConsole(AoSession aoSession)
       {
           // Add the context variables to the sheet.
           NameIterator nameIterator = aoSession.listContext("*");
           int count = nameIterator.getCount();
           String key;
           for (int i = 0; i < count; i++)
           {
               key = nameIterator.nextOne();
               System.Console.Write(key);
               System.Console.Write(": ");
               System.Console.WriteLine (aoSession.getContextByName(key).value.u.GetstringVal());
           }
       }
      /*
       * Write the session context values to an MS-Office EXCEL sheet.
       */
       /*
      static private void sessionContextToExcel(AoSession aoSession) {
          Excel.Application oXL;
          Excel._Workbook oWB;
          Excel._Worksheet oSheet;
          Excel.Range oRng;

         try {
            //Start Excel and get Application object.
            oXL = new Excel.Application();
            oXL.Visible = true;

            //Get a new workbook.
            oWB = (Excel._Workbook)(oXL.Workbooks.Add("ASAM ODS Conext"));
            oSheet = (Excel._Worksheet)oWB.ActiveSheet;

            // Add the context variables to the sheet.
            NameIterator nameIterator = aoSession.listContext("*");
            int count = nameIterator.getCount();
            String key;
            for (int i=0; i<count; i++) {
               key = nameIterator.nextOne();
               oSheet.Cells[1, i] = key;
               oSheet.Cells[2, i] = aoSession.getContextByName(key).value.u.GetstringVal();   
            }

            //Make sure Excel is visible and give the user control
            //of Microsoft Excel's lifetime.
            oXL.Visible = true;
            oXL.UserControl = true;
         } catch (Exception theException) {
            String errorMessage;
            errorMessage = "Error: ";
            errorMessage = String.Concat(errorMessage, theException.Message);
            errorMessage = String.Concat(errorMessage, " Line: ");
            errorMessage = String.Concat(errorMessage, theException.Source);
            System.Console.WriteLine(errorMessage);
         }
      }
        */
   }
}
